@@ -1,16 +1,14 @@
 package String::Multibyte::EUC;
 
 use vars qw($VERSION);
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 +{
     charset  => 'EUC',
 
     regexp   => '(?:[\x00-\x7F]|[\xA1-\xFE][\xA1-\xFE])',
 
-    cmpchar => sub {
-	length($_[0]) <=> length($_[1]) || $_[0] cmp $_[1];
-    },
+    cmpchar => sub { $_[0] cmp $_[1] },
 
     nextchar => sub {
 	my $ch = shift;
@@ -39,7 +37,7 @@ __END__
 =head1 NAME
 
 String::Multibyte::EUC - internally used by String::Multibyte
-for EUC encodings
+for simple EUC encodings
 
 =head1 SYNOPSIS
 
@@ -53,6 +51,15 @@ for EUC encodings
 C<String::Multibyte::EUC> is used for manipulation of strings in EUC
 comprising C<C0>, C<G0>, and C<G1> in which a double-byte set is invoked.
 
+Byte range of single-byte characters:
+C<0x00..0x7F>.
+
+Leading byte range of double-byte characters:
+C<0xA1..0xFE>.
+
+Trailing byte range of double-byte characters:
+C<0xA1..0xFE>.
+
 Character order: C<0x00..0x7F>, C<0xA1A1..0xFEFE>
 
 =head1 CAVEAT
